<?php 
/*
Plugin Name: Glamix Instagram Shop
Plugin URI: http://glamix.me
Description: Glamix is a wordpress plugin that lets fashion bloggers showcase their Instagram feed in their blog and enable their followers to shop any fashion item they see and love from their Instagram feed.
Version: 1.0.0
Author: Glamix
Author URI: http://glamix.me
License: GPLv2 or later
*/

/* Constants */
define('WP_DEBUG', true );
define('WP_DEBUG_DISPLAY', true );

define('GLAMIX_DIR', plugin_dir_path(__FILE__));
define('GLAMIX_URL', plugin_dir_url(__FILE__));

define('GLAMIX_IG_AUTH_OPTION', 'glamix_access_token');
define('GLAMIX_IG_USERID_OPTION', 'glamix_user_id');
define('GLAMIX_IG_USERNAME_OPTION', 'glamix_user_name');

/* Requires */
require_once(GLAMIX_DIR . 'wp-syte-admin-functions.php');

/* Hooks */

register_activation_hook( __FILE__, 'glamix_instagram_activate' );
register_deactivation_hook( __FILE__, 'glamix_instagram_deactivate' );
register_uninstall_hook( __FILE__, 'glamix_instagram_uninstall' );

/* Actions - Admin */

add_action('admin_menu', 'glamix_admin_menu');
add_action('admin_init', 'glamix_register_settings');

add_action('admin_enqueue_scripts', 'glamix_load_admin_scripts');
add_action('admin_enqueue_scripts', 'glamix_load_admin_styles');

add_action('wp_ajax_reset_access', 'reset_access_callback' );

/* Actions - Front-end */

add_action('wp_enqueue_scripts', 'glamix_load_scripts');
add_action('wp_enqueue_scripts', 'glamix_load_styles');
add_action('wp_footer', 'glamix_wp_footer', -1);

/* Methods - Hooks */

function glamix_instagram_activate() {
  glamix_activate();
}

function glamix_instagram_deactivate() {
  glamix_deactivate();
}

function glamix_instagram_uninstall() {
  glamix_uninstall();
}

// Methods - Actions - Admin

function glamix_admin_menu() {
	add_menu_page(
		'Glamix Settings',   //page title
		'Glamix Settings',  //menu title
		'manage_options',   //capability
		'glamix_settings',   //menu_slug
		'glamix_admin_page',  //function
		 plugin_dir_url( __FILE__ ) . '/images/glamix_wp.png'  //icon_url
	);
}

function glamix_admin_page() {
	if ( isset($_GET['access_token']) && isset($_GET['user_name']) && isset($_GET['user_id']) ) {
		update_option(GLAMIX_IG_AUTH_OPTION, $_GET['access_token']);
		update_option(GLAMIX_IG_USERNAME_OPTION, $_GET['user_name']);
		update_option(GLAMIX_IG_USERID_OPTION, $_GET['user_id']);
		?>
		<script>
			jQuery(document).ready(function(){
				jQuery('form').submit();
			});
		</script>
		<?php
	}
	?>
	<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
	
	<form method="post" action="admin.php?page=glamix_settings" class="glamix-signin-form">
		<input type="hidden" id="glamix_user_id" name="<?php echo GLAMIX_OPT . '[glamix_user_id]' ?>">
		<?php
			do_settings_sections('settings_glamix');
			if (get_option(GLAMIX_IG_AUTH_OPTION) != '' || get_option(GLAMIX_IG_USERID_OPTION) != '' || get_option(GLAMIX_IG_USERNAME_OPTION) != '') {
				?>
				<div id="glamix-reset-access" class="button button-secondary">Reset Access</div>
				<?php
			}
			?>
		<script>
			jQuery(document).ready(function(){
				jQuery('#glamix-reset-access').on('click',function(){
					var data = {
						'action': 'reset_access'
					};

					jQuery.post(ajaxurl, data, function(response) {
						console.log(response)
						jQuery('form').submit();
					});
				});
			});
		</script>
	</form>
	<?php
}

function glamix_register_settings(){

	$settings = glamix_getsettings();

	add_settings_section('glamix_configure_section', 'Configure', 'glamix_configure_section_callback', 'settings_glamix');
	
	foreach ($settings as $setting_name => $setting) {
		if (isset($setting['field_or_not']) === true && $setting['field_or_not'] !== 'no_field') {
			add_settings_field(
				$setting_name,
				$setting['title'],
				'glamix_admin_setting_field_callback',
				'settings_glamix',
				$setting['section'],
				array($setting)
			);
		}
	}
}

function glamix_configure_section_callback(){
	$the_url = urlencode(admin_url('admin.php?page=glamix_settings')) . '&response_type=token';
	if (get_option(GLAMIX_IG_AUTH_OPTION) == '' || get_option(GLAMIX_IG_USERID_OPTION) == '' || get_option(GLAMIX_IG_USERNAME_OPTION) == '') {
		?>
		<a href="http://wp.glamix.me/authorize_user?redirect_url=<?php echo $the_url;?>">
			<div id="glamix-signin-button" class="button button-secondary">Sign In with Instagram</div>
		</a>
		<div class="glamix-signin-error">Please sign in.</div>
		<?php
	}
}

function reset_access_callback() {
	update_option(GLAMIX_IG_AUTH_OPTION, '');
	update_option(GLAMIX_IG_USERNAME_OPTION, '');
	update_option(GLAMIX_IG_USERID_OPTION, '');
	
	echo 'OK';
	
	wp_die();
}

function glamix_load_admin_scripts($hook){
	if ($_GET['page'] !== 'glamix_settings' ) {
		return;
	}
	
}

function glamix_load_admin_styles($hook){
	if ($_GET['page'] !== 'glamix_settings' ) {
		return;
	}
	
	wp_enqueue_style('glamix_admin_css', plugins_url('css/glamix_admin_css.css', __FILE__));
}

// Methods - Actions - Front-end

function glamix_load_scripts($hook) {
	$access_token = get_option(GLAMIX_IG_AUTH_OPTION);
	$user_id = get_option(GLAMIX_IG_USERID_OPTION);
	
	if (empty($access_token) && empty($user_id)) {
		return;
	}

	$obj = glamix_load_instagram_posts($access_token, $user_id);
	$handle = 'glamix_script';
	$js_ver  = date("ymd-Gis", filemtime(plugin_dir_path( __FILE__) . 'js/glamix_client.js' ));

	wp_enqueue_script('syte-script', '//syteapi.com/assets/imajs.js?a=100&sig=H5HOnxUr8zf1eHfkye6yUIvUrQBpP27z43cQuFZfecg=');
	wp_enqueue_script('slick-carousel', plugins_url('js/slick.min.js', __FILE__), array('jquery'));
	wp_enqueue_script($handle, plugins_url('js/glamix_client.js', __FILE__), array('slick-carousel'), $my_js_ver);
	wp_localize_script($handle, '_glamix', $obj);
}

function glamix_load_styles($hook) {
	$access_token = get_option(GLAMIX_IG_AUTH_OPTION);
	$user_id = get_option(GLAMIX_IG_USERID_OPTION);

	if (empty($access_token) && empty($user_id)) {
		return;
	}

	$handle = 'glamix_style';

	wp_enqueue_style('slick-carousel', plugins_url('css/slick.css', __FILE__));
	wp_enqueue_style('slick-carousel-theme', plugins_url('css/slick-theme.css', __FILE__));
	wp_enqueue_style($handle, plugins_url('css/glamix_client_css.css', __FILE__));
}

function glamix_load_instagram_posts($access_token, $user_id) {
	$api_url = 'https://api.instagram.com/v1/users/'.$user_id.'/media/recent/?access_token='.$access_token;
	$ig_posts_response = wp_remote_get($api_url);

	if (is_wp_error($ig_posts_response)) {
		return json_encode(array('error','Error getting IG posts'));
	}

	$response_json = wp_remote_retrieve_body($ig_posts_response);

	/* Check ig response code is good*/
	$code = json_decode($response_json)->meta->code;
	if ($code != 200) {
		return json_encode(array('error', json_decode($response_json)->meta->error_message));
	}

	/* No data (posts) in response for any reason */
	if (!property_exists(json_decode($response_json), 'data')) {
		return json_encode(array('error', 'Error retrieving posts data'));
	}

	/* No posts on user */
	if (empty(json_decode($response_json)->data)) {
		return json_encode(array('error', 'User has no posts'));
	}

	return json_decode($response_json)->data;
}

function glamix_wp_footer() {
	$access_token = get_option(GLAMIX_IG_AUTH_OPTION);
	$user_id = get_option(GLAMIX_IG_USERID_OPTION);
	$user_name = get_option(GLAMIX_IG_USERNAME_OPTION);

	if (empty($access_token) && empty($user_id)) {
		return;
	}

	echo '<div class="glamix-instagram-container"><h1 class="shop-header">Shop My Instagram <b>@'.$user_name.'</b></h1><div id="glamix-carousel" class="glamix-carousel-container"></div></div>';
	exit();
}